OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nie je možné zapisovat do priečinka \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do priečinka s konfiguráciou.",
    "See %s" : "Pozri %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "To je zvyčajne možné opraviť tým, že %s udelíte webovému serveru oprávnenie na zápis k adresáru s konfiguráciou%s.",
    "Sample configuration detected" : "Detekovaná bola vzorová konfigurácia",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zistilo sa, že konfigurácia bola skopírovaná zo vzorových súborov. Takáto konfigurácia nie je podporovaná a môže poškodiť vašu inštaláciu. Prečítajte si dokumentáciu pred vykonaním zmien v config.php",
    "PHP %s or higher is required." : "Požadovaná verzia PHP %s alebo vyššia.",
    "PHP with a version lower than %s is required." : "PHP je vyžadované vo vyššej verzii ako %s.",
    "%sbit or higher PHP required." : "Vyžaduje sa PHP %sbit alebo vyššie.",
    "Following databases are supported: %s" : "Podporované sú tieto databázy: %s",
    "The command line tool %s could not be found" : "Nástroj príkazového riadka %s nebol nájdený",
    "The library %s is not available." : "Knižnica %s je nedostupná.",
    "Library %s with a version higher than %s is required - available version %s." : "Požadovaná je knižnica %s vo vyššej verzii ako %s - dostupná verzia %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Požadovaná je knižnica %s v nižšej verzii ako %s - dostupná verzia %s.",
    "Following platforms are supported: %s" : "Podporované sú nasledovné systémy: %s",
    "ownCloud %s or higher is required." : "Požadovaná verzia ownCloudu %s alebo vyššia.",
    "ownCloud %s or lower is required." : "Požadovaná verzia ownCloudu %s alebo nižšia.",
    "Unknown filetype" : "Neznámy typ súboru",
    "Invalid image" : "Chybný obrázok",
    "today" : "dnes",
    "yesterday" : "včera",
    "_%n day ago_::_%n days ago_" : ["včera","pred %n dňami","pred %n dňami"],
    "last month" : "minulý mesiac",
    "_%n month ago_::_%n months ago_" : ["pred %n mesiacom","pred %n mesiacmi","pred %n mesiacmi"],
    "last year" : "minulý rok",
    "_%n year ago_::_%n years ago_" : ["vlani","pred %n rokmi","pred %n rokmi"],
    "_%n hour ago_::_%n hours ago_" : ["pred %n hodinou","pred %n hodinami","pred %n hodinami"],
    "_%n minute ago_::_%n minutes ago_" : ["pred %n minútou","pred %n minútami","pred %n minútami"],
    "seconds ago" : "pred sekundami",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID: %s neexistuje. Povoľte ho prosím vo vašom nastavení aplikácií alebo konaktujte správcu.",
    "Builtin" : "Vstavaný",
    "None" : "Žiadny",
    "Username and password" : "Meno a heslo",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "Empty filename is not allowed" : "Prázdny názov súboru nie je povolený",
    "Dot files are not allowed" : "Názov súboru začínajúci bodkou nie je povolený.",
    "4-byte characters are not supported in file names" : "V názve súbou nie sú podporované 4-bajtové znaky.",
    "File name is a reserved word" : "Názov súboru je rezervované slovo.",
    "File name contains at least one invalid character" : "Názov súboru obsahuje nepovolené znaky.",
    "File name is too long" : "Meno súboru je veľmi dlhé.",
    "App directory already exists" : "Aplikačný priečinok už existuje",
    "Can't create app folder. Please fix permissions. %s" : "Nemožno vytvoriť aplikačný priečinok. Prosím upravte povolenia. %s",
    "Archive does not contain a directory named %s" : "Archív neobsahuje priečinok zvaný %s",
    "No source specified when installing app" : "Nešpecifikovaný zdroj pri inštalácii aplikácie",
    "No href specified when installing app from http" : "Nešpecifikovaný atribút \"href\" pri inštalácii aplikácie pomocou protokolu \"http\"",
    "No path specified when installing app from local file" : "Nešpecifikovaná cesta pri inštalácii aplikácie z lokálneho súboru",
    "Archives of type %s are not supported" : "Tento typ archívu %s nie je podporovaný",
    "Failed to open archive when installing app" : "Zlyhanie pri otváraní archívu počas inštalácie aplikácie",
    "App does not provide an info.xml file" : "Aplikácia neposkytuje súbor info.xml",
    "App cannot be installed because appinfo file cannot be read." : "Aplikáciu nebolo možné nainštalovať, pretože nie je možné prečítať súbor appinfo.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Podpis nebolo možné skontrolovať. Prosím, kontaktujte vývojára aplikácie a pozrite sa na vašu obrazovku správcu.",
    "App can't be installed because of not allowed code in the App" : "Aplikácia nemôže byť nainštalovaná pre nepovolený kód v aplikácii",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikácia nemôže byť nainštalovaná pre nekompatibilitu z touto verziou ownCloudu",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikácia nemôže byť nainštalovaná pretože obsahuje značku<shipped>true</shipped>, ktorá nie je povolená pre nedodávané aplikácie",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Aplikáciu nebolo možné nainštalovať, pretože verzia v info.xml nie je rovnaká ako verzia nahlásená z app store.",
    "Apps" : "Aplikácie",
    "General" : "Všeobecné",
    "Storage" : "Úložisko",
    "Security" : "Zabezpečenie",
    "Encryption" : "Šifrovanie",
    "Sharing" : "Zdieľanie",
    "Search" : "Hľadať",
    "Updates" : "Aktualizácie",
    "%s enter the database username and name." : "%s zadajte používateľské meno do databázy a meno.",
    "%s enter the database username." : "Zadajte používateľské meno %s databázy.",
    "%s enter the database name." : "Zadajte názov databázy pre %s databázy.",
    "%s you may not use dots in the database name" : "V názve databázy %s nemôžete používať bodky",
    "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
    "Oracle username and/or password not valid" : "Používateľské meno a/alebo heslo pre Oracle databázu je neplatné",
    "DB Error: \"%s\"" : "Chyba DB: \"%s\"",
    "Offending command was: \"%s\"" : "Podozrivý príkaz bol: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Musíte zadať jestvujúci účet alebo administrátora.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Podozrivý príkaz bol: \"%s\", meno: %s, heslo: %s",
    "PostgreSQL username and/or password not valid" : "Používateľské meno a/alebo heslo pre PostgreSQL databázu je neplatné",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použite ho na vlastné riziko!",
    "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
    "Set an admin username." : "Zadajte používateľské meno administrátora.",
    "Set an admin password." : "Zadajte heslo administrátora.",
    "Can't create or write into the data directory %s" : "Nemožno vytvoriť alebo zapisovať do priečinka dát %s",
    "Invalid Federated Cloud ID" : "Neplatné združené Cloud ID",
    "%s shared »%s« with you" : "%s s vami zdieľa »%s«",
    "%s via %s" : "%s cez %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Zdieľanie %s zlyhalo, pretože backend nepodporuje typ zdieľania %i",
    "Sharing %s failed, because the file does not exist" : "Zdieľanie %s zlyhalo, pretože súbor neexistuje",
    "You are not allowed to share %s" : "Nemôžete zdieľať %s",
    "Sharing %s failed, because you can not share with yourself" : "Zdieľanie %s zlyhalo, pretože nemôžete zdieľať sami so sebou.",
    "Sharing %s failed, because the user %s does not exist" : "Zdieľanie %s zlyhalo, pretože používateľ %s neexistuje",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Zdieľanie %s zlyhalo, pretože používateľ %s nie je členom žiadnej skupiny spoločnej s používateľom %s",
    "Sharing %s failed, because this item is already shared with %s" : "Zdieľanie %s zlyhalo, pretože táto položka už je zdieľaná s %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Zdieľanie %s zlyhalo, položka je už zdieľaná s používateľom %s",
    "Sharing %s failed, because the group %s does not exist" : "Zdieľanie %s zlyhalo, pretože skupina %s neexistuje",
    "Sharing %s failed, because %s is not a member of the group %s" : "Zdieľanie %s zlyhalo, pretože %s nie je členom skupiny %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Musíte zadať heslo ak chcete vytvoriť verejný odkaz, lebo iba odkazy chránené heslom sú povolené",
    "Sharing %s failed, because sharing with links is not allowed" : "Zdieľanie %s zlyhalo, pretože zdieľanie odkazom nie je povolené",
    "Not allowed to create a federated share with the same user" : "Nie je dovolené vytvoriť feredované zdieľanie s rovnakým používateľom.",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Zdieľanie %s zlyhalo, nepodarilo sa nájsť %s, možno je server v súčasnej dobe nedostupný.",
    "Share type %s is not valid for %s" : "Typ zdieľania %s nie je platný pre %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nastavenie povolení pre %s zlyhalo, pretože povolenia prekračujú povolenia udelené %s",
    "Setting permissions for %s failed, because the item was not found" : "Nastavenie povolení pre %s zlyhalo, pretože položka sa nenašla",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nie je možné nastaviť dátum konca platnosti. Zdieľania nemôžu skončiť neskôr ako %s po zdieľaní.",
    "Cannot set expiration date. Expiration date is in the past" : "Nie je možné nastaviť dátum konca platnosti. Dátum konca platnosti je v minulosti.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Nemožno vymazať čas expirácie. Pri zdieľaní je čas expirácie vyžadovaný.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend zdieľania %s musí implementovať rozhranie OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend zdieľania %s nebol nájdený",
    "Sharing backend for %s not found" : "Backend zdieľania pre %s nebol nájdený",
    "Sharing failed, because the user %s is the original sharer" : "Zdieľanie zlyhalo, pretože %s je pôvodný používateľ, ktorý zdieľa.",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Zdieľanie %s zlyhalo, pretože povolenia prekračujú povolenia udelené %s",
    "Sharing %s failed, because resharing is not allowed" : "Zdieľanie %s zlyhalo, pretože zdieľanie ďalším nie je povolené",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Zdieľanie %s zlyhalo, backend zdieľania nenašiel zdrojový %s",
    "Sharing %s failed, because the file could not be found in the file cache" : "Zdieľanie %s zlyhalo, pretože súbor sa nenašiel vo vyrovnávacej pamäti súborov",
    "Cannot increase permissions of %s" : "Nie je možné zvýšiť oprávnenia %s",
    "Files can't be shared with delete permissions" : "Súbory nie je možné zdieľať s oprávnením na mazanie",
    "Files can't be shared with create permissions" : "Súbory nie je možné zdieľať s oprávnením na vytvorenie",
    "Expiration date is in the past" : "Dátum vypršania platnosti je v minulosti",
    "Cannot set expiration date more than %s days in the future" : "Nie je možné nastaviť dátum vypršania platnosti viac ako %s dní do budúcnosti",
    "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V používateľskom mene sú povolené iba nasledovné znaky: „a-z“, „A-Z“, „0-9“ a „_.@-'“",
    "A valid username must be provided" : "Musíte zadať platné používateľské meno",
    "Username contains whitespace at the beginning or at the end" : "Používateľské meno obsahuje na začiatku alebo na konci netlačiteľné znaky",
    "A valid password must be provided" : "Musíte zadať platné heslo",
    "The username is already being used" : "Meno používateľa je už použité",
    "Login canceled by app" : "Aplikácia zrušila prihlásenie",
    "User disabled" : "Používateľ je deaktivovaný",
    "Help" : "Pomoc",
    "Settings" : "Nastavenia",
    "Users" : "Používatelia",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikáciu \"%s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %s",
    "web services under your control" : "webové služby pod Vašou kontrolou",
    "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
    "Can't read file" : "Nemožno čítať súbor.",
    "Application is not enabled" : "Aplikácia nie je zapnutá",
    "Authentication error" : "Chyba autentifikácie",
    "Token expired. Please reload page." : "Token vypršal. Obnovte, prosím, stránku.",
    "Unknown user" : "Neznámy používateľ",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ovládače databázy (sqlite, mysql, alebo postgresql) nie sú nainštalované.",
    "Cannot write into \"config\" directory" : "Nie je možné zapisovať do priečinka \"config\"",
    "Cannot write into \"apps\" directory" : "Nie je možné zapisovať do priečinka \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Toto je zvyčajne možné opraviť tým, že %s udelíte webovému serveru oprávnenie na zápis do priečinka aplikácií %s alebo vypnete obchod s aplikáciami v konfiguračnom súbore.",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "To sa zvyčajne dá opraviť <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">nastavením prístupu na zápis webovému serveru do koreňového adresára</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Oprávnenia je zvyčajne možné opraviť tým, že %sudelíte webovému serveru oprávnenie na zápis do koreňového priečinka%s.",
    "Setting locale to %s failed" : "Nastavenie locale na %s zlyhalo",
    "Please install one of these locales on your system and restart your webserver." : "Prosím, nainštalujte si aspoň jeden z týchto jazykov so svojho systému a reštartujte webserver.",
    "Please ask your server administrator to install the module." : "Prosím, požiadajte administrátora vášho servera o inštaláciu modulu.",
    "PHP module %s not installed." : "PHP modul %s nie je nainštalovaný.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Voľba PHP „%s“ nie je nastavená na „%s“.",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Zmenou tejto voľby v php.ini znovu uvediete váš ownCloud do prevádzky",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastavený na \"%s\", namiesto predpokladanej hodnoty \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vužaduje sa libxml2 aspoň verzie 2.7.0. Momentálne je nainštalovaná %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Aby ste opravili tento problém, aktualizujte svoju verziu libxml2 a reštartujte webový server.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly boli nainštalované, ale stále sa tvária, že chýbajú?",
    "Please ask your server administrator to restart the web server." : "Prosím, požiadajte administrátora vášho servera o reštartovanie webového servera.",
    "PostgreSQL >= 9 required" : "Vyžadované PostgreSQL >= 9",
    "Please upgrade your database version" : "Prosím, aktualizujte verziu svojej databázy",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť.",
    "Check the value of \"datadirectory\" in your configuration" : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Prosím, skontrolujte, či priečinok dát obsahuje súbor \".ocdata\".",
    "Could not obtain lock type %d on \"%s\"." : "Nepodarilo sa získať zámok typu %d na „%s“.",
    "Storage unauthorized. %s" : "Neoprávnené úložisko. %s",
    "Storage incomplete configuration. %s" : "Neúplná konfigurácia úložiska. %s",
    "Storage connection error. %s" : "Chyba pripojenia k úložisku. %s",
    "Storage connection timeout. %s" : "Čas na nadviazanie pripojenia k úložisku vypršal. %s"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
